@@ -5,18 +5,29 @@ import objc
 from PyObjCTools.TestSupport import *
 from DictionaryServices import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+try:
+    long
+except NameError:
+    long = int
+
 class TestDictionaryServices (TestCase):
     def testClasses(self):
         self.assertIsCFType(DCSDictionaryRef)
 
     
     def testFunctions(self):
-        r = DCSGetTermRangeInString(None, u"the hello world program", 5)
+        txt = b"the hello world program".decode('latin1')
+        r = DCSGetTermRangeInString(None, txt, 5)
         self.assertIsInstance(r, CFRange)
         self.assertEqual(r, (4, 5))
 
-        r = DCSCopyTextDefinition(None, u"the hello world program", r)
-        self.assertIsInstance(r, unicode)
+        r = DCSCopyTextDefinition(None, txt, r)
+        self.assertIsInstance(r, (unicode, type(None)))
 
         v = DCSDictionaryGetTypeID()
         self.assertIsInstance(v, (int, long))
